@@ -19,23 +19,16 @@ Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA.
 
 */
 // Self
-#include "croptool.moc"
+#include "croptool.h"
 
 // Qt
-#include <qmath.h>
-#include <QApplication>
-#include <QFlags>
+#include <QtMath>
 #include <QGraphicsSceneMouseEvent>
-#include <QMouseEvent>
 #include <QPainter>
 #include <QRect>
-#include <QScrollBar>
-#include <QTimer>
-#include <QToolButton>
+#include <QDebug>
 
 // KDE
-#include <KDebug>
-#include <KDialog>
 
 // Local
 #include <lib/documentview/rasterimageview.h>
